/*
 * Hamlib Rotator backend - SPID Rot2Prog
 * Copyright (c) 2009 by Norvald H. Ryeng, LA6YKA
 *
 * $Id$
 *
 * This library is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#ifndef _ROT_SPID_H
#define _ROT_SPID_H 1

extern const struct rot_caps spid_rot1prog_rot_caps;
extern const struct rot_caps spid_rot2prog_rot_caps;

#endif /* _ROT_SPID_H */
